@@ -2,6 +2,7 @@ package HTML::FormFu::Element::Date;
 
 use strict;
 use base 'HTML::FormFu::Element::Multi';
+use MRO::Compat;
 use mro 'c3';
 
 use HTML::FormFu::Util qw( _filter_components _parse_args );
@@ -152,10 +153,30 @@ sub _date_defaults {
     my $default;
 
     if ( defined( $default = $self->default_natural ) ) {
-        my $parser = DateTime::Format::Natural->new;
-        $default = $parser->parse_datetime($default);
+        my $parser;
+        
+        if ( defined( my $datetime_args = $self->default_datetime_args ) ) {
+            if ( exists $datetime_args->{set_time_zone} ) {
+                my $tz = $datetime_args->{set_time_zone};
+                $parser = DateTime::Format::Natural->new( time_zone => $tz );
+            }
+            else {
+                $parser = DateTime::Format::Natural->new;
+            }
+        }
+        else {
+            $parser = DateTime::Format::Natural->new;
+        }
+        $default = $parser->parse_datetime( $default );
     }
     elsif ( defined( $default = $self->default ) && length $default ) {
+        
+        if ( !$self->form->submitted || $self->render_processed_value ) {
+            for my $deflator ( @{ $self->_deflators } ) {
+                $default = $deflator->process($default);
+            }
+        }
+        
         my $is_blessed = blessed($default);
 
         if ( !$is_blessed || ( $is_blessed && !$default->isa('DateTime') ) ) {
@@ -299,8 +320,8 @@ sub _build_month_list {
             if ( !$@ ) {
                 @months
                     = $month->{short_names}
-                    ? @{ $loc->month_abbreviations }
-                    : @{ $loc->month_names };
+                    ? @{ $loc->month_format_abbreviated }
+                    : @{ $loc->month_format_wide };
 
                 @months = map {ucfirst} @months;
 
